@@ -1,4 +1,4 @@
-const sha1 = require('js-sha1');
+//const sha1 = require('js-sha1');
 exports.render = function (req, res) {
     res.render('index', {
         'title': "Hello",
@@ -86,7 +86,7 @@ exports.report = function (req, res) {
     };
     //var type = req.param("type");
     //req.logger.info(type);
-    res.ireport("report1.jasper", "pdf", datas, parameters);
+    res.ireport("report1.jasper", "word", datas, parameters);
 }
 
 exports.userinfo = function (req, res) {
